# pklib
This project is intend to reduce the effort of working in machine learning process

Version 0.0.1
    -   Test Project Uploaded

Version 0.0.2
    - Project Update Check

Version 0.0.3
    - Libraries update to call

Version 0.0.4
    - Imported Preprocessor from pklibs

Version 0.0.5
    - Unintended df bug solved in Data Encoders
